==> huaweicloudsdkiotedge-3.1.141-py2.py3-none-any.whl: huaweicloudsdkiotedge/v2/model/delete_dc_points_req_dto.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class DeleteDcPointsReqDTO:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'points': 'list[str]'
    }

    attribute_map = {
        'points': 'points'
    }

    def __init__(self, points=None):
        """DeleteDcPointsReqDTO

        The model defined in huaweicloud sdk

        :param points: 
        :type points: list[str]
        """
        
        

        self._points = None
        self.discriminator = None

        self.points = points

    @property
    def points(self):
        """Gets the points of this DeleteDcPointsReqDTO.

        :return: The points of this DeleteDcPointsReqDTO.
        :rtype: list[str]
        """
        return self._points

    @points.setter
    def points(self, points):
        """Sets the points of this DeleteDcPointsReqDTO.

        :param points: The points of this DeleteDcPointsReqDTO.
        :type points: list[str]
        """
        self._points = points

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeleteDcPointsReqDTO):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkiotedge-3.1.151-py2.py3-none-any.whl: huaweicloudsdkiotedge/v2/model/delete_dc_points_req_dto.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class DeleteDcPointsReqDTO:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'points': 'list[str]'
    }

    attribute_map = {
        'points': 'points'
    }

    def __init__(self, points=None):
        r"""DeleteDcPointsReqDTO

        The model defined in huaweicloud sdk

        :param points: 
        :type points: list[str]
        """
        
        

        self._points = None
        self.discriminator = None

        self.points = points

    @property
    def points(self):
        r"""Gets the points of this DeleteDcPointsReqDTO.

        :return: The points of this DeleteDcPointsReqDTO.
        :rtype: list[str]
        """
        return self._points

    @points.setter
    def points(self, points):
        r"""Sets the points of this DeleteDcPointsReqDTO.

        :param points: The points of this DeleteDcPointsReqDTO.
        :type points: list[str]
        """
        self._points = points

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeleteDcPointsReqDTO):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
